@@ -114,6 +114,15 @@ public:
      */
     static bool init(const char *program = NULL);
 
+    /**
+     * Initialize secure stack with fips support.  If fips support is not
+     * successfully enabled, the secure stack is also not initialized.  Hence
+     * init() can be used for non-fips certified operation if fips fails.
+     * @param program name we are initializing for.
+     * @return true if fips support enabled and stack initialized.
+     */
+    static bool fips(const char *program = NULL);
+
     /**
      * Get a certificate path.  This is used to get directories for application
      * specific certificate stores.
@@ -291,10 +300,19 @@ public:
 
         void set(const char *cipher);
 
+        void set(const char *cipher, const char *digest);
+
+        void assign(const char *key, size_t size, const unsigned char *salt, unsigned rounds);
+
     public:
         Key(const char *cipher, const char *digest, const char *text, size_t size = 0, const unsigned char *salt = NULL, unsigned rounds = 1);
+
+        Key(const char *cipher, const char *digest);
+
         ~Key();
 
+        void assign(const char *key, size_t size = 0);
+
         void clear(void);
 
         inline size_t size(void)
@@ -308,6 +326,11 @@ public:
 
         inline bool operator!()
             {return keysize == 0;};
+
+        inline Key& operator=(const char *pass)
+            {assign(pass); return *this;};
+
+        static void options(const unsigned char *salt = NULL, unsigned rounds = 1);
     };
 
     typedef Key *key_t;
